@@ -24,3 +24,18 @@ def read_json(infile):
         except json.decoder.JSONDecodeError:
             data = []
     return data
+
+
+def save_json(datadict,outfile):
+    """Saves dict to a json file
+
+    Parameters
+    ----------
+    datadict : dict
+        json object (dict)
+    outfile : str
+        Full path to json output file
+    """
+    with open(outfile,'w') as f:
+        json.dump(datadict,f)
+    return
